Index: src/wp-includes/pluggable.php
===================================================================
--- src/wp-includes/pluggable.php	(revision 27505)
+++ src/wp-includes/pluggable.php	(working copy)
@@ -248,8 +248,7 @@
 			$tempheaders = $headers;
 		}
 		$headers = array();
-		$cc = array();
-		$bcc = array();
+		$cc = $bcc = $reply_to = array();
 
 		// If it's actually got contents
 		if ( !empty( $tempheaders ) ) {
@@ -305,6 +304,9 @@
 					case 'bcc':
 						$bcc = array_merge( (array) $bcc, explode( ',', $content ) );
 						break;
+					case 'reply-to':
+						$reply_to = array_merge( (array) $reply_to, explode( ',', $content ) );
+						break;
 					default:
 						// Add it to our grand headers array
 						$headers[trim( $name )] = trim( $content );
@@ -370,39 +372,36 @@
 	$phpmailer->Subject = $subject;
 	$phpmailer->Body    = $message;
 
-	// Add any CC and BCC recipients
-	if ( !empty( $cc ) ) {
-		foreach ( (array) $cc as $recipient ) {
-			try {
-				// Break $recipient into name and address parts if in the format "Foo <bar@baz.com>"
-				$recipient_name = '';
-				if( preg_match( '/(.*)<(.+)>/', $recipient, $matches ) ) {
-					if ( count( $matches ) == 3 ) {
-						$recipient_name = $matches[1];
-						$recipient = $matches[2];
+	// Add any CC, BCC, and Reply-To recipients
+	foreach ( array( 'cc', 'bcc', 'reply_to' ) as $recipient_header ) {
+		if ( ! empty( $$recipient_header ) ) {
+			foreach ( $$recipient_header as $recipient ) {
+				try {
+					// Break $recipient into name and address parts if in the format "Foo <bar@baz.com>"
+					$recipient_name = '';
+					if( preg_match( '/(.*)<(.+)>/', $recipient, $matches ) ) {
+						if ( count( $matches ) == 3 ) {
+							$recipient_name = $matches[1];
+							$recipient = $matches[2];
+						}
 					}
-				}
-				$phpmailer->AddCc( $recipient, $recipient_name );
-			} catch ( phpmailerException $e ) {
-				continue;
-			}
-		}
-	}
+					
+					switch ( $recipient_header ) {
+						case 'cc':
+							$phpmailer->AddCC( $recipient, $recipient_name );
+						break;
 
-	if ( !empty( $bcc ) ) {
-		foreach ( (array) $bcc as $recipient) {
-			try {
-				// Break $recipient into name and address parts if in the format "Foo <bar@baz.com>"
-				$recipient_name = '';
-				if( preg_match( '/(.*)<(.+)>/', $recipient, $matches ) ) {
-					if ( count( $matches ) == 3 ) {
-						$recipient_name = $matches[1];
-						$recipient = $matches[2];
+						case 'bcc':
+							$phpmailer->AddBcc( $recipient, $recipient_name );
+						break;
+
+						case 'reply_to':
+							$phpmailer->AddReplyTo( $recipient, $recipient_name );
+						break;
 					}
+				} catch ( phpmailerException $e ) {
+					continue;
 				}
-				$phpmailer->AddBcc( $recipient, $recipient_name );
-			} catch ( phpmailerException $e ) {
-				continue;
 			}
 		}
 	}
